@@ -6,9 +6,9 @@ from abilian.app import Application
 from abilian.core.signals import register_js_api
 from abilian.web import url_for
 
-from .criterion import BaseCriterion, TextSearchCriterion
+# from .criterion import BaseCriterion, TextSearchCriterion
 
-__all__ = ["BaseCriterion", "TextSearchCriterion"]
+# __all__ = ["BaseCriterion", "TextSearchCriterion"]
 
 
 def _do_register_js_api(sender: Application):
